@@ -75,6 +75,7 @@ def do(argv):
                         size=stat_source.st_size,
                     )
                 else:
+                    print(f'file ({round(sized / max_size * 1024, 2)} MB) : {full_path_dest} exists.')
                     apend_res = True
             if apend_res is False:
                 break
@@ -86,10 +87,13 @@ def do(argv):
         if not os.path.exists(dir_dst):
             os.makedirs(dir_dst)
 
-        copyfile(src, dst)
-        print(f'Copied ({i} from {len(files)}) {src} -> {dst}')
-        i += 1
-        sized += size
+        try:
+            copyfile(src, dst)
+            print(f'Copied ({i} from {len(files)}) {src} -> {dst}')
+            i += 1
+            sized += size
+        except FileNotFoundError as ex:
+            print(ex)
 
     if sized > 0:
         git_push(dest_path=dest_path)
